CA19_Cl03.html
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Video |
clickAndWait | link=Añadir vídeo |
type | id_name | nuevo vídeo
type | id_file | /home/fgil/Escritorio/merengue/selenium/test-data/test_image.jpg
clickAndWait | _save |
verifyTextPresent | Video file must be in flv format |
clickAndWait | link=Terminar sesión |